@@ -15,7 +15,13 @@ from kuber.latest.core_v1 import ObjectReference
 class Event(_kuber_definitions.Resource):
     """
     Event is a report of an event somewhere in the cluster. It
-    generally denotes some state change in the system.
+    generally denotes some state change in the system. Events
+    have a limited retention time and triggers and messages may
+    evolve with time.  Event consumers should not rely on the
+    timing of an event with a given Reason reflecting a
+    consistent underlying trigger, or the continued existence of
+    events with that Reason.  Events should be treated as
+    informative, best-effort, supplemental data.
     """
 
     def __init__(
