@@ -18,251 +18,238 @@ class APIService(_kuber_definitions.Resource):
     """
 
     def __init__(
-            self,
-            metadata: 'ObjectMeta' = None,
-            spec: 'APIServiceSpec' = None,
-            status: 'APIServiceStatus' = None,
+        self,
+        metadata: "ObjectMeta" = None,
+        spec: "APIServiceSpec" = None,
+        status: "APIServiceStatus" = None,
     ):
         """Create APIService instance."""
         super(APIService, self).__init__(
-            api_version='apiregistration.k8s.io/v1',
-            kind='APIService'
+            api_version="apiregistration.k8s.io/v1", kind="APIService"
         )
         self._properties = {
-            'metadata': metadata if metadata is not None else ObjectMeta(),
-            'spec': spec if spec is not None else APIServiceSpec(),
-            'status': status if status is not None else APIServiceStatus(),
-
+            "metadata": metadata if metadata is not None else ObjectMeta(),
+            "spec": spec if spec is not None else APIServiceSpec(),
+            "status": status if status is not None else APIServiceStatus(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'kind': (str, None),
-            'metadata': (ObjectMeta, None),
-            'spec': (APIServiceSpec, None),
-            'status': (APIServiceStatus, None),
-
+            "apiVersion": (str, None),
+            "kind": (str, None),
+            "metadata": (ObjectMeta, None),
+            "spec": (APIServiceSpec, None),
+            "status": (APIServiceStatus, None),
         }
 
     @property
-    def metadata(self) -> 'ObjectMeta':
-        """
-
-        """
-        return self._properties.get('metadata')
+    def metadata(self) -> "ObjectMeta":
+        """"""
+        return typing.cast(
+            "ObjectMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ObjectMeta', dict]):
-        """
-
-        """
+    def metadata(self, value: typing.Union["ObjectMeta", dict]):
+        """"""
         if isinstance(value, dict):
-            value = ObjectMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ObjectMeta,
+                ObjectMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @property
-    def spec(self) -> 'APIServiceSpec':
+    def spec(self) -> "APIServiceSpec":
         """
         Spec contains information for locating and communicating
         with a server
         """
-        return self._properties.get('spec')
+        return typing.cast(
+            "APIServiceSpec",
+            self._properties.get("spec"),
+        )
 
     @spec.setter
-    def spec(self, value: typing.Union['APIServiceSpec', dict]):
+    def spec(self, value: typing.Union["APIServiceSpec", dict]):
         """
         Spec contains information for locating and communicating
         with a server
         """
         if isinstance(value, dict):
-            value = APIServiceSpec().from_dict(value)
-        self._properties['spec'] = value
+            value = typing.cast(
+                APIServiceSpec,
+                APIServiceSpec().from_dict(value),
+            )
+        self._properties["spec"] = value
 
     @property
-    def status(self) -> 'APIServiceStatus':
+    def status(self) -> "APIServiceStatus":
         """
         Status contains derived information about an API server
         """
-        return self._properties.get('status')
+        return typing.cast(
+            "APIServiceStatus",
+            self._properties.get("status"),
+        )
 
     @status.setter
-    def status(self, value: typing.Union['APIServiceStatus', dict]):
+    def status(self, value: typing.Union["APIServiceStatus", dict]):
         """
         Status contains derived information about an API server
         """
         if isinstance(value, dict):
-            value = APIServiceStatus().from_dict(value)
-        self._properties['status'] = value
+            value = typing.cast(
+                APIServiceStatus,
+                APIServiceStatus().from_dict(value),
+            )
+        self._properties["status"] = value
 
-    def create_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'APIServiceStatus':
+    def create_resource(self, namespace: "str" = None) -> "APIServiceStatus":
         """
         Creates the APIService in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the create is complete.
         """
-        names = [
-            'create_namespaced_api_service',
-            'create_api_service'
-        ]
+        names = ["create_namespaced_api_service", "create_api_service"]
 
         response = _kube_api.execute(
-            action='create',
+            action="create",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict()}
-        )
-        return (
-            APIServiceStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'APIServiceStatus':
+        output = APIServiceStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def replace_resource(self, namespace: "str" = None) -> "APIServiceStatus":
         """
         Replaces the APIService in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
-        names = [
-            'replace_namespaced_api_service',
-            'replace_api_service'
-        ]
+        names = ["replace_namespaced_api_service", "replace_api_service"]
 
         response = _kube_api.execute(
-            action='replace',
+            action="replace",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            APIServiceStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(
-            self,
-            namespace: 'str' = None
-    ) -> 'APIServiceStatus':
+        output = APIServiceStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def patch_resource(self, namespace: "str" = None) -> "APIServiceStatus":
         """
         Patches the APIService in the currently
         configured Kubernetes cluster and returns the status information
         returned by the Kubernetes API after the replace is complete.
         """
-        names = [
-            'patch_namespaced_api_service',
-            'patch_api_service'
-        ]
+        names = ["patch_namespaced_api_service", "patch_api_service"]
 
         response = _kube_api.execute(
-            action='patch',
+            action="patch",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'body': self.to_dict(), 'name': self.metadata.name}
-        )
-        return (
-            APIServiceStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(
-            self,
-            namespace: 'str' = None
-    ) -> 'APIServiceStatus':
+        output = APIServiceStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def get_resource_status(self, namespace: "str" = None) -> "APIServiceStatus":
         """
         Returns status information about the given resource within the cluster.
         """
-        names = [
-            'read_namespaced_api_service',
-            'read_api_service'
-        ]
+        names = ["read_namespaced_api_service", "read_api_service"]
 
         response = _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
-        )
-        return (
-            APIServiceStatus()
-            .from_dict(_kube_api.to_kuber_dict(response.status))
+            api_args={"name": self.metadata.name},
         )
 
-    def read_resource(
-            self,
-            namespace: str = None
-    ):
+        output = APIServiceStatus()
+        if response is not None:
+            output.from_dict(_kube_api.to_kuber_dict(response.status))
+        return output
+
+    def read_resource(self, namespace: str = None):
         """
         Reads the APIService from the currently configured
         Kubernetes cluster and returns the low-level definition object.
         """
         names = [
-            'read_namespaced_api_service',
-            'read_api_service'
+            "read_namespaced_api_service",
+            "read_api_service",
         ]
         return _kube_api.execute(
-            action='read',
+            action="read",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name}
+            api_args={"name": self.metadata.name},
         )
 
     def delete_resource(
-            self,
-            namespace: str = None,
-            propagation_policy: str = 'Foreground',
-            grace_period_seconds: int = 10
+        self,
+        namespace: str = None,
+        propagation_policy: str = "Foreground",
+        grace_period_seconds: int = 10,
     ):
         """
         Deletes the APIService from the currently configured
         Kubernetes cluster.
         """
         names = [
-            'delete_namespaced_api_service',
-            'delete_api_service'
+            "delete_namespaced_api_service",
+            "delete_api_service",
         ]
 
         body = client.V1DeleteOptions(
             propagation_policy=propagation_policy,
-            grace_period_seconds=grace_period_seconds
+            grace_period_seconds=grace_period_seconds,
         )
 
         _kube_api.execute(
-            action='delete',
+            action="delete",
             resource=self,
             names=names,
             namespace=namespace,
             api_client=None,
-            api_args={'name': self.metadata.name, 'body': body}
+            api_args={"name": self.metadata.name, "body": body},
         )
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.ApiregistrationV1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.ApiregistrationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.ApiregistrationV1Api(**kwargs)
 
-    def __enter__(self) -> 'APIService':
+    def __enter__(self) -> "APIService":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -276,33 +263,32 @@ class APIServiceCondition(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            last_transition_time: str = None,
-            message: str = None,
-            reason: str = None,
-            status: str = None,
-            type_: str = None,
+        self,
+        last_transition_time: str = None,
+        message: str = None,
+        reason: str = None,
+        status: str = None,
+        type_: str = None,
     ):
         """Create APIServiceCondition instance."""
         super(APIServiceCondition, self).__init__(
-            api_version='apiregistration.k8s.io/v1',
-            kind='APIServiceCondition'
+            api_version="apiregistration.k8s.io/v1", kind="APIServiceCondition"
         )
         self._properties = {
-            'lastTransitionTime': last_transition_time if last_transition_time is not None else None,
-            'message': message if message is not None else '',
-            'reason': reason if reason is not None else '',
-            'status': status if status is not None else '',
-            'type': type_ if type_ is not None else '',
-
+            "lastTransitionTime": last_transition_time
+            if last_transition_time is not None
+            else None,
+            "message": message if message is not None else "",
+            "reason": reason if reason is not None else "",
+            "status": status if status is not None else "",
+            "type": type_ if type_ is not None else "",
         }
         self._types = {
-            'lastTransitionTime': (str, None),
-            'message': (str, None),
-            'reason': (str, None),
-            'status': (str, None),
-            'type': (str, None),
-
+            "lastTransitionTime": (str, None),
+            "message": (str, None),
+            "reason": (str, None),
+            "status": (str, None),
+            "type": (str, None),
         }
 
     @property
@@ -311,22 +297,24 @@ class APIServiceCondition(_kuber_definitions.Definition):
         Last time the condition transitioned from one status to
         another.
         """
-        return self._properties.get('lastTransitionTime')
+        return typing.cast(
+            str,
+            self._properties.get("lastTransitionTime"),
+        )
 
     @last_transition_time.setter
     def last_transition_time(
-            self,
-            value: typing.Union[str, _datetime.datetime, _datetime.date]
+        self, value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
         Last time the condition transitioned from one status to
         another.
         """
         if isinstance(value, _datetime.datetime):
-            value = value.strftime('%Y-%m-%dT%H:%M:%SZ')
+            value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
         elif isinstance(value, _datetime.date):
-            value = value.strftime('%Y-%m-%dT00:00:00Z')
-        self._properties['lastTransitionTime'] = value
+            value = value.strftime("%Y-%m-%dT00:00:00Z")
+        self._properties["lastTransitionTime"] = value
 
     @property
     def message(self) -> str:
@@ -334,7 +322,10 @@ class APIServiceCondition(_kuber_definitions.Definition):
         Human-readable message indicating details about last
         transition.
         """
-        return self._properties.get('message')
+        return typing.cast(
+            str,
+            self._properties.get("message"),
+        )
 
     @message.setter
     def message(self, value: str):
@@ -342,7 +333,7 @@ class APIServiceCondition(_kuber_definitions.Definition):
         Human-readable message indicating details about last
         transition.
         """
-        self._properties['message'] = value
+        self._properties["message"] = value
 
     @property
     def reason(self) -> str:
@@ -350,7 +341,10 @@ class APIServiceCondition(_kuber_definitions.Definition):
         Unique, one-word, CamelCase reason for the condition's last
         transition.
         """
-        return self._properties.get('reason')
+        return typing.cast(
+            str,
+            self._properties.get("reason"),
+        )
 
     @reason.setter
     def reason(self, value: str):
@@ -358,7 +352,7 @@ class APIServiceCondition(_kuber_definitions.Definition):
         Unique, one-word, CamelCase reason for the condition's last
         transition.
         """
-        self._properties['reason'] = value
+        self._properties["reason"] = value
 
     @property
     def status(self) -> str:
@@ -366,7 +360,10 @@ class APIServiceCondition(_kuber_definitions.Definition):
         Status is the status of the condition. Can be True, False,
         Unknown.
         """
-        return self._properties.get('status')
+        return typing.cast(
+            str,
+            self._properties.get("status"),
+        )
 
     @status.setter
     def status(self, value: str):
@@ -374,23 +371,26 @@ class APIServiceCondition(_kuber_definitions.Definition):
         Status is the status of the condition. Can be True, False,
         Unknown.
         """
-        self._properties['status'] = value
+        self._properties["status"] = value
 
     @property
     def type_(self) -> str:
         """
         Type is the type of the condition.
         """
-        return self._properties.get('type')
+        return typing.cast(
+            str,
+            self._properties.get("type"),
+        )
 
     @type_.setter
     def type_(self, value: str):
         """
         Type is the type of the condition.
         """
-        self._properties['type'] = value
+        self._properties["type"] = value
 
-    def __enter__(self) -> 'APIServiceCondition':
+    def __enter__(self) -> "APIServiceCondition":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -403,80 +403,77 @@ class APIServiceList(_kuber_definitions.Collection):
     """
 
     def __init__(
-            self,
-            items: typing.List['APIService'] = None,
-            metadata: 'ListMeta' = None,
+        self,
+        items: typing.List["APIService"] = None,
+        metadata: "ListMeta" = None,
     ):
         """Create APIServiceList instance."""
         super(APIServiceList, self).__init__(
-            api_version='apiregistration.k8s.io/v1',
-            kind='APIServiceList'
+            api_version="apiregistration.k8s.io/v1", kind="APIServiceList"
         )
         self._properties = {
-            'items': items if items is not None else [],
-            'metadata': metadata if metadata is not None else ListMeta(),
-
+            "items": items if items is not None else [],
+            "metadata": metadata if metadata is not None else ListMeta(),
         }
         self._types = {
-            'apiVersion': (str, None),
-            'items': (list, APIService),
-            'kind': (str, None),
-            'metadata': (ListMeta, None),
-
+            "apiVersion": (str, None),
+            "items": (list, APIService),
+            "kind": (str, None),
+            "metadata": (ListMeta, None),
         }
 
     @property
-    def items(self) -> typing.List['APIService']:
-        """
-
-        """
-        return self._properties.get('items')
+    def items(self) -> typing.List["APIService"]:
+        """"""
+        return typing.cast(
+            typing.List["APIService"],
+            self._properties.get("items"),
+        )
 
     @items.setter
-    def items(
-            self,
-            value: typing.Union[typing.List['APIService'], typing.List[dict]]
-    ):
-        """
-
-        """
-        cleaned = []
+    def items(self, value: typing.Union[typing.List["APIService"], typing.List[dict]]):
+        """"""
+        cleaned: typing.List[APIService] = []
         for item in value:
             if isinstance(item, dict):
-                item = APIService().from_dict(item)
-            cleaned.append(item)
-        self._properties['items'] = cleaned
+                item = typing.cast(
+                    APIService,
+                    APIService().from_dict(item),
+                )
+            cleaned.append(typing.cast(APIService, item))
+        self._properties["items"] = cleaned
 
     @property
-    def metadata(self) -> 'ListMeta':
-        """
-
-        """
-        return self._properties.get('metadata')
+    def metadata(self) -> "ListMeta":
+        """"""
+        return typing.cast(
+            "ListMeta",
+            self._properties.get("metadata"),
+        )
 
     @metadata.setter
-    def metadata(self, value: typing.Union['ListMeta', dict]):
-        """
-
-        """
+    def metadata(self, value: typing.Union["ListMeta", dict]):
+        """"""
         if isinstance(value, dict):
-            value = ListMeta().from_dict(value)
-        self._properties['metadata'] = value
+            value = typing.cast(
+                ListMeta,
+                ListMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
 
     @staticmethod
     def get_resource_api(
-            api_client: client.ApiClient = None,
-            **kwargs
-    ) -> 'client.ApiregistrationV1Api':
+        api_client: client.ApiClient = None, **kwargs
+    ) -> "client.ApiregistrationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
         this object.
         """
         if api_client:
-            kwargs['apl_client'] = api_client
+            kwargs["apl_client"] = api_client
         return client.ApiregistrationV1Api(**kwargs)
 
-    def __enter__(self) -> 'APIServiceList':
+    def __enter__(self) -> "APIServiceList":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -491,39 +488,42 @@ class APIServiceSpec(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            ca_bundle: str = None,
-            group: str = None,
-            group_priority_minimum: int = None,
-            insecure_skip_tlsverify: bool = None,
-            service: 'ServiceReference' = None,
-            version: str = None,
-            version_priority: int = None,
+        self,
+        ca_bundle: str = None,
+        group: str = None,
+        group_priority_minimum: int = None,
+        insecure_skip_tlsverify: bool = None,
+        service: "ServiceReference" = None,
+        version: str = None,
+        version_priority: int = None,
     ):
         """Create APIServiceSpec instance."""
         super(APIServiceSpec, self).__init__(
-            api_version='apiregistration.k8s.io/v1',
-            kind='APIServiceSpec'
+            api_version="apiregistration.k8s.io/v1", kind="APIServiceSpec"
         )
         self._properties = {
-            'caBundle': ca_bundle if ca_bundle is not None else '',
-            'group': group if group is not None else '',
-            'groupPriorityMinimum': group_priority_minimum if group_priority_minimum is not None else None,
-            'insecureSkipTLSVerify': insecure_skip_tlsverify if insecure_skip_tlsverify is not None else None,
-            'service': service if service is not None else ServiceReference(),
-            'version': version if version is not None else '',
-            'versionPriority': version_priority if version_priority is not None else None,
-
+            "caBundle": ca_bundle if ca_bundle is not None else "",
+            "group": group if group is not None else "",
+            "groupPriorityMinimum": group_priority_minimum
+            if group_priority_minimum is not None
+            else None,
+            "insecureSkipTLSVerify": insecure_skip_tlsverify
+            if insecure_skip_tlsverify is not None
+            else None,
+            "service": service if service is not None else ServiceReference(),
+            "version": version if version is not None else "",
+            "versionPriority": version_priority
+            if version_priority is not None
+            else None,
         }
         self._types = {
-            'caBundle': (str, None),
-            'group': (str, None),
-            'groupPriorityMinimum': (int, None),
-            'insecureSkipTLSVerify': (bool, None),
-            'service': (ServiceReference, None),
-            'version': (str, None),
-            'versionPriority': (int, None),
-
+            "caBundle": (str, None),
+            "group": (str, None),
+            "groupPriorityMinimum": (int, None),
+            "insecureSkipTLSVerify": (bool, None),
+            "service": (ServiceReference, None),
+            "version": (str, None),
+            "versionPriority": (int, None),
         }
 
     @property
@@ -533,7 +533,10 @@ class APIServiceSpec(_kuber_definitions.Definition):
         validate an API server's serving certificate. If
         unspecified, system trust roots on the apiserver are used.
         """
-        return self._properties.get('caBundle')
+        return typing.cast(
+            str,
+            self._properties.get("caBundle"),
+        )
 
     @ca_bundle.setter
     def ca_bundle(self, value: str):
@@ -542,21 +545,24 @@ class APIServiceSpec(_kuber_definitions.Definition):
         validate an API server's serving certificate. If
         unspecified, system trust roots on the apiserver are used.
         """
-        self._properties['caBundle'] = value
+        self._properties["caBundle"] = value
 
     @property
     def group(self) -> str:
         """
         Group is the API group name this server hosts
         """
-        return self._properties.get('group')
+        return typing.cast(
+            str,
+            self._properties.get("group"),
+        )
 
     @group.setter
     def group(self, value: str):
         """
         Group is the API group name this server hosts
         """
-        self._properties['group'] = value
+        self._properties["group"] = value
 
     @property
     def group_priority_minimum(self) -> int:
@@ -574,7 +580,10 @@ class APIServiceSpec(_kuber_definitions.Definition):
         extensions) at 18000 and PaaSes (OpenShift, Deis) are
         recommended to be in the 2000s
         """
-        return self._properties.get('groupPriorityMinimum')
+        return typing.cast(
+            int,
+            self._properties.get("groupPriorityMinimum"),
+        )
 
     @group_priority_minimum.setter
     def group_priority_minimum(self, value: int):
@@ -592,7 +601,7 @@ class APIServiceSpec(_kuber_definitions.Definition):
         extensions) at 18000 and PaaSes (OpenShift, Deis) are
         recommended to be in the 2000s
         """
-        self._properties['groupPriorityMinimum'] = value
+        self._properties["groupPriorityMinimum"] = value
 
     @property
     def insecure_skip_tlsverify(self) -> bool:
@@ -601,7 +610,10 @@ class APIServiceSpec(_kuber_definitions.Definition):
         when communicating with this server. This is strongly
         discouraged.  You should use the CABundle instead.
         """
-        return self._properties.get('insecureSkipTLSVerify')
+        return typing.cast(
+            bool,
+            self._properties.get("insecureSkipTLSVerify"),
+        )
 
     @insecure_skip_tlsverify.setter
     def insecure_skip_tlsverify(self, value: bool):
@@ -610,10 +622,10 @@ class APIServiceSpec(_kuber_definitions.Definition):
         when communicating with this server. This is strongly
         discouraged.  You should use the CABundle instead.
         """
-        self._properties['insecureSkipTLSVerify'] = value
+        self._properties["insecureSkipTLSVerify"] = value
 
     @property
-    def service(self) -> 'ServiceReference':
+    def service(self) -> "ServiceReference":
         """
         Service is a reference to the service for this API server.
         It must communicate on port 443. If the Service is nil, that
@@ -621,10 +633,13 @@ class APIServiceSpec(_kuber_definitions.Definition):
         locally on this server. The call will simply delegate to the
         normal handler chain to be fulfilled.
         """
-        return self._properties.get('service')
+        return typing.cast(
+            "ServiceReference",
+            self._properties.get("service"),
+        )
 
     @service.setter
-    def service(self, value: typing.Union['ServiceReference', dict]):
+    def service(self, value: typing.Union["ServiceReference", dict]):
         """
         Service is a reference to the service for this API server.
         It must communicate on port 443. If the Service is nil, that
@@ -633,8 +648,11 @@ class APIServiceSpec(_kuber_definitions.Definition):
         normal handler chain to be fulfilled.
         """
         if isinstance(value, dict):
-            value = ServiceReference().from_dict(value)
-        self._properties['service'] = value
+            value = typing.cast(
+                ServiceReference,
+                ServiceReference().from_dict(value),
+            )
+        self._properties["service"] = value
 
     @property
     def version(self) -> str:
@@ -642,7 +660,10 @@ class APIServiceSpec(_kuber_definitions.Definition):
         Version is the API version this server hosts.  For example,
         "v1"
         """
-        return self._properties.get('version')
+        return typing.cast(
+            str,
+            self._properties.get("version"),
+        )
 
     @version.setter
     def version(self, value: str):
@@ -650,7 +671,7 @@ class APIServiceSpec(_kuber_definitions.Definition):
         Version is the API version this server hosts.  For example,
         "v1"
         """
-        self._properties['version'] = value
+        self._properties["version"] = value
 
     @property
     def version_priority(self) -> int:
@@ -673,7 +694,10 @@ class APIServiceSpec(_kuber_definitions.Definition):
         v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2,
         foo1, foo10.
         """
-        return self._properties.get('versionPriority')
+        return typing.cast(
+            int,
+            self._properties.get("versionPriority"),
+        )
 
     @version_priority.setter
     def version_priority(self, value: int):
@@ -696,9 +720,9 @@ class APIServiceSpec(_kuber_definitions.Definition):
         v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2,
         foo1, foo10.
         """
-        self._properties['versionPriority'] = value
+        self._properties["versionPriority"] = value
 
-    def __enter__(self) -> 'APIServiceSpec':
+    def __enter__(self) -> "APIServiceSpec":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -712,46 +736,48 @@ class APIServiceStatus(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            conditions: typing.List['APIServiceCondition'] = None,
+        self,
+        conditions: typing.List["APIServiceCondition"] = None,
     ):
         """Create APIServiceStatus instance."""
         super(APIServiceStatus, self).__init__(
-            api_version='apiregistration.k8s.io/v1',
-            kind='APIServiceStatus'
+            api_version="apiregistration.k8s.io/v1", kind="APIServiceStatus"
         )
         self._properties = {
-            'conditions': conditions if conditions is not None else [],
-
+            "conditions": conditions if conditions is not None else [],
         }
         self._types = {
-            'conditions': (list, APIServiceCondition),
-
+            "conditions": (list, APIServiceCondition),
         }
 
     @property
-    def conditions(self) -> typing.List['APIServiceCondition']:
+    def conditions(self) -> typing.List["APIServiceCondition"]:
         """
         Current service state of apiService.
         """
-        return self._properties.get('conditions')
+        return typing.cast(
+            typing.List["APIServiceCondition"],
+            self._properties.get("conditions"),
+        )
 
     @conditions.setter
     def conditions(
-            self,
-            value: typing.Union[typing.List['APIServiceCondition'], typing.List[dict]]
+        self, value: typing.Union[typing.List["APIServiceCondition"], typing.List[dict]]
     ):
         """
         Current service state of apiService.
         """
-        cleaned = []
+        cleaned: typing.List[APIServiceCondition] = []
         for item in value:
             if isinstance(item, dict):
-                item = APIServiceCondition().from_dict(item)
-            cleaned.append(item)
-        self._properties['conditions'] = cleaned
+                item = typing.cast(
+                    APIServiceCondition,
+                    APIServiceCondition().from_dict(item),
+                )
+            cleaned.append(typing.cast(APIServiceCondition, item))
+        self._properties["conditions"] = cleaned
 
-    def __enter__(self) -> 'APIServiceStatus':
+    def __enter__(self) -> "APIServiceStatus":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -764,27 +790,24 @@ class ServiceReference(_kuber_definitions.Definition):
     """
 
     def __init__(
-            self,
-            name: str = None,
-            namespace: str = None,
-            port: int = None,
+        self,
+        name: str = None,
+        namespace: str = None,
+        port: int = None,
     ):
         """Create ServiceReference instance."""
         super(ServiceReference, self).__init__(
-            api_version='apiregistration.k8s.io/v1',
-            kind='ServiceReference'
+            api_version="apiregistration.k8s.io/v1", kind="ServiceReference"
         )
         self._properties = {
-            'name': name if name is not None else '',
-            'namespace': namespace if namespace is not None else '',
-            'port': port if port is not None else None,
-
+            "name": name if name is not None else "",
+            "namespace": namespace if namespace is not None else "",
+            "port": port if port is not None else None,
         }
         self._types = {
-            'name': (str, None),
-            'namespace': (str, None),
-            'port': (int, None),
-
+            "name": (str, None),
+            "namespace": (str, None),
+            "port": (int, None),
         }
 
     @property
@@ -792,28 +815,34 @@ class ServiceReference(_kuber_definitions.Definition):
         """
         Name is the name of the service
         """
-        return self._properties.get('name')
+        return typing.cast(
+            str,
+            self._properties.get("name"),
+        )
 
     @name.setter
     def name(self, value: str):
         """
         Name is the name of the service
         """
-        self._properties['name'] = value
+        self._properties["name"] = value
 
     @property
     def namespace(self) -> str:
         """
         Namespace is the namespace of the service
         """
-        return self._properties.get('namespace')
+        return typing.cast(
+            str,
+            self._properties.get("namespace"),
+        )
 
     @namespace.setter
     def namespace(self, value: str):
         """
         Namespace is the namespace of the service
         """
-        self._properties['namespace'] = value
+        self._properties["namespace"] = value
 
     @property
     def port(self) -> int:
@@ -822,7 +851,10 @@ class ServiceReference(_kuber_definitions.Definition):
         Default to 443 for backward compatibility. `port` should be
         a valid port number (1-65535, inclusive).
         """
-        return self._properties.get('port')
+        return typing.cast(
+            int,
+            self._properties.get("port"),
+        )
 
     @port.setter
     def port(self, value: int):
@@ -831,9 +863,9 @@ class ServiceReference(_kuber_definitions.Definition):
         Default to 443 for backward compatibility. `port` should be
         a valid port number (1-65535, inclusive).
         """
-        self._properties['port'] = value
+        self._properties["port"] = value
 
-    def __enter__(self) -> 'ServiceReference':
+    def __enter__(self) -> "ServiceReference":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
