@@ -6,13 +6,13 @@ from kuber import versioning
 # package and kuber metadata around its creation and labeling within the
 # kuber library.
 KUBERNETES_VERSION = versioning.KubernetesVersion(
-    label="v1.21",
-    version="v1.21.0-alpha.0",
+    label="v1.15",
+    version="v1.15.12",
     major="1",
-    minor="21",
-    patch="0",
-    pre_release="alpha.0",
+    minor="15",
+    patch="12",
+    pre_release="",
     build="",
-    created_at=_datetime.datetime(2020, 12, 8),
-    commit_sha="98bc258bf5516b6c60860e06845b899eab29825d",
+    created_at=_datetime.datetime(2020, 12, 30),
+    commit_sha="e2a822d9f3c2fdb5c9bfbe64313cf9f657f0a725",
 )
