@@ -4,9 +4,9 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_21.meta_v1 import LabelSelector
-from kuber.v1_21.meta_v1 import ListMeta
-from kuber.v1_21.meta_v1 import ObjectMeta
+from kuber.v1_17.meta_v1 import LabelSelector
+from kuber.v1_17.meta_v1 import ListMeta
+from kuber.v1_17.meta_v1 import ObjectMeta
 
 
 class MutatingWebhook(_kuber_definitions.Definition):
@@ -938,10 +938,8 @@ class RuleWithOperations(_kuber_definitions.Definition):
     def operations(self) -> typing.List[str]:
         """
         Operations is the operations the admission hook cares about
-        - CREATE, UPDATE, DELETE, CONNECT or * for all of those
-        operations and any future admission operations that are
-        added. If '*' is present, the length of the slice must be
-        one. Required.
+        - CREATE, UPDATE, or * for all operations. If '*' is
+        present, the length of the slice must be one. Required.
         """
         return typing.cast(
             typing.List[str],
@@ -952,10 +950,8 @@ class RuleWithOperations(_kuber_definitions.Definition):
     def operations(self, value: typing.List[str]):
         """
         Operations is the operations the admission hook cares about
-        - CREATE, UPDATE, DELETE, CONNECT or * for all of those
-        operations and any future admission operations that are
-        added. If '*' is present, the length of the slice must be
-        one. Required.
+        - CREATE, UPDATE, or * for all operations. If '*' is
+        present, the length of the slice must be one. Required.
         """
         self._properties["operations"] = value
 
