@@ -5,23 +5,17 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_21.core_v1 import EventSource
-from kuber.v1_21.meta_v1 import ListMeta
-from kuber.v1_21.meta_v1 import MicroTime
-from kuber.v1_21.meta_v1 import ObjectMeta
-from kuber.v1_21.core_v1 import ObjectReference
+from kuber.v1_17.core_v1 import EventSource
+from kuber.v1_17.meta_v1 import ListMeta
+from kuber.v1_17.meta_v1 import MicroTime
+from kuber.v1_17.meta_v1 import ObjectMeta
+from kuber.v1_17.core_v1 import ObjectReference
 
 
 class Event(_kuber_definitions.Resource):
     """
     Event is a report of an event somewhere in the cluster. It
-    generally denotes some state change in the system. Events
-    have a limited retention time and triggers and messages may
-    evolve with time.  Event consumers should not rely on the
-    timing of an event with a given Reason reflecting a
-    consistent underlying trigger, or the continued existence of
-    events with that Reason.  Events should be treated as
-    informative, best-effort, supplemental data.
+    generally denotes some state change in the system.
     """
 
     def __init__(
@@ -96,9 +90,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def action(self) -> str:
         """
-        action is what action was taken/failed regarding to the
-        regarding object. It is machine-readable. This field can
-        have at most 128 characters.
+        What action was taken/failed regarding to the regarding
+        object.
         """
         return typing.cast(
             str,
@@ -108,17 +101,16 @@ class Event(_kuber_definitions.Resource):
     @action.setter
     def action(self, value: str):
         """
-        action is what action was taken/failed regarding to the
-        regarding object. It is machine-readable. This field can
-        have at most 128 characters.
+        What action was taken/failed regarding to the regarding
+        object.
         """
         self._properties["action"] = value
 
     @property
     def deprecated_count(self) -> int:
         """
-        deprecatedCount is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return typing.cast(
             int,
@@ -128,16 +120,16 @@ class Event(_kuber_definitions.Resource):
     @deprecated_count.setter
     def deprecated_count(self, value: int):
         """
-        deprecatedCount is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         self._properties["deprecatedCount"] = value
 
     @property
     def deprecated_first_timestamp(self) -> str:
         """
-        deprecatedFirstTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return typing.cast(
             str,
@@ -149,8 +141,8 @@ class Event(_kuber_definitions.Resource):
         self, value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
-        deprecatedFirstTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         if isinstance(value, _datetime.datetime):
             value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -161,8 +153,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def deprecated_last_timestamp(self) -> str:
         """
-        deprecatedLastTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return typing.cast(
             str,
@@ -174,8 +166,8 @@ class Event(_kuber_definitions.Resource):
         self, value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
-        deprecatedLastTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         if isinstance(value, _datetime.datetime):
             value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -186,8 +178,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def deprecated_source(self) -> "EventSource":
         """
-        deprecatedSource is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return typing.cast(
             "EventSource",
@@ -197,8 +189,8 @@ class Event(_kuber_definitions.Resource):
     @deprecated_source.setter
     def deprecated_source(self, value: typing.Union["EventSource", dict]):
         """
-        deprecatedSource is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -210,8 +202,7 @@ class Event(_kuber_definitions.Resource):
     @property
     def event_time(self) -> "MicroTime":
         """
-        eventTime is the time when this Event was first observed. It
-        is required.
+        Required. Time when this Event was first observed.
         """
         return typing.cast(
             "MicroTime",
@@ -221,8 +212,7 @@ class Event(_kuber_definitions.Resource):
     @event_time.setter
     def event_time(self, value: typing.Union["MicroTime", dict]):
         """
-        eventTime is the time when this Event was first observed. It
-        is required.
+        Required. Time when this Event was first observed.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -252,7 +242,7 @@ class Event(_kuber_definitions.Resource):
     @property
     def note(self) -> str:
         """
-        note is a human-readable description of the status of this
+        Optional. A human-readable description of the status of this
         operation. Maximal length of the note is 1kB, but libraries
         should be prepared to handle values up to 64kB.
         """
@@ -264,7 +254,7 @@ class Event(_kuber_definitions.Resource):
     @note.setter
     def note(self, value: str):
         """
-        note is a human-readable description of the status of this
+        Optional. A human-readable description of the status of this
         operation. Maximal length of the note is 1kB, but libraries
         should be prepared to handle values up to 64kB.
         """
@@ -273,8 +263,7 @@ class Event(_kuber_definitions.Resource):
     @property
     def reason(self) -> str:
         """
-        reason is why the action was taken. It is human-readable.
-        This field can have at most 128 characters.
+        Why the action was taken.
         """
         return typing.cast(
             str,
@@ -284,19 +273,17 @@ class Event(_kuber_definitions.Resource):
     @reason.setter
     def reason(self, value: str):
         """
-        reason is why the action was taken. It is human-readable.
-        This field can have at most 128 characters.
+        Why the action was taken.
         """
         self._properties["reason"] = value
 
     @property
     def regarding(self) -> "ObjectReference":
         """
-        regarding contains the object this Event is about. In most
-        cases it's an Object reporting controller implements, e.g.
-        ReplicaSetController implements ReplicaSets and this event
-        is emitted because it acts on some changes in a ReplicaSet
-        object.
+        The object this Event is about. In most cases it's an Object
+        reporting controller implements. E.g. ReplicaSetController
+        implements ReplicaSets and this event is emitted because it
+        acts on some changes in a ReplicaSet object.
         """
         return typing.cast(
             "ObjectReference",
@@ -306,11 +293,10 @@ class Event(_kuber_definitions.Resource):
     @regarding.setter
     def regarding(self, value: typing.Union["ObjectReference", dict]):
         """
-        regarding contains the object this Event is about. In most
-        cases it's an Object reporting controller implements, e.g.
-        ReplicaSetController implements ReplicaSets and this event
-        is emitted because it acts on some changes in a ReplicaSet
-        object.
+        The object this Event is about. In most cases it's an Object
+        reporting controller implements. E.g. ReplicaSetController
+        implements ReplicaSets and this event is emitted because it
+        acts on some changes in a ReplicaSet object.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -322,9 +308,9 @@ class Event(_kuber_definitions.Resource):
     @property
     def related(self) -> "ObjectReference":
         """
-        related is the optional secondary object for more complex
-        actions. E.g. when regarding object triggers a creation or
-        deletion of related object.
+        Optional secondary object for more complex actions. E.g.
+        when regarding object triggers a creation or deletion of
+        related object.
         """
         return typing.cast(
             "ObjectReference",
@@ -334,9 +320,9 @@ class Event(_kuber_definitions.Resource):
     @related.setter
     def related(self, value: typing.Union["ObjectReference", dict]):
         """
-        related is the optional secondary object for more complex
-        actions. E.g. when regarding object triggers a creation or
-        deletion of related object.
+        Optional secondary object for more complex actions. E.g.
+        when regarding object triggers a creation or deletion of
+        related object.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -348,9 +334,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def reporting_controller(self) -> str:
         """
-        reportingController is the name of the controller that
-        emitted this Event, e.g. `kubernetes.io/kubelet`. This field
-        cannot be empty for new Events.
+        Name of the controller that emitted this Event, e.g.
+        `kubernetes.io/kubelet`.
         """
         return typing.cast(
             str,
@@ -360,18 +345,15 @@ class Event(_kuber_definitions.Resource):
     @reporting_controller.setter
     def reporting_controller(self, value: str):
         """
-        reportingController is the name of the controller that
-        emitted this Event, e.g. `kubernetes.io/kubelet`. This field
-        cannot be empty for new Events.
+        Name of the controller that emitted this Event, e.g.
+        `kubernetes.io/kubelet`.
         """
         self._properties["reportingController"] = value
 
     @property
     def reporting_instance(self) -> str:
         """
-        reportingInstance is the ID of the controller instance, e.g.
-        `kubelet-xyzf`. This field cannot be empty for new Events
-        and it can have at most 128 characters.
+        ID of the controller instance, e.g. `kubelet-xyzf`.
         """
         return typing.cast(
             str,
@@ -381,17 +363,15 @@ class Event(_kuber_definitions.Resource):
     @reporting_instance.setter
     def reporting_instance(self, value: str):
         """
-        reportingInstance is the ID of the controller instance, e.g.
-        `kubelet-xyzf`. This field cannot be empty for new Events
-        and it can have at most 128 characters.
+        ID of the controller instance, e.g. `kubelet-xyzf`.
         """
         self._properties["reportingInstance"] = value
 
     @property
     def series(self) -> "EventSeries":
         """
-        series is data about the Event series this event represents
-        or nil if it's a singleton Event.
+        Data about the Event series this event represents or nil if
+        it's a singleton Event.
         """
         return typing.cast(
             "EventSeries",
@@ -401,8 +381,8 @@ class Event(_kuber_definitions.Resource):
     @series.setter
     def series(self, value: typing.Union["EventSeries", dict]):
         """
-        series is data about the Event series this event represents
-        or nil if it's a singleton Event.
+        Data about the Event series this event represents or nil if
+        it's a singleton Event.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -414,8 +394,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def type_(self) -> str:
         """
-        type is the type of this event (Normal, Warning), new types
-        could be added in the future. It is machine-readable.
+        Type of this event (Normal, Warning), new types could be
+        added in the future.
         """
         return typing.cast(
             str,
@@ -425,8 +405,8 @@ class Event(_kuber_definitions.Resource):
     @type_.setter
     def type_(self, value: str):
         """
-        type is the type of this event (Normal, Warning), new types
-        could be added in the future. It is machine-readable.
+        Type of this event (Normal, Warning), new types could be
+        added in the future.
         """
         self._properties["type"] = value
 
@@ -574,7 +554,7 @@ class EventList(_kuber_definitions.Collection):
     @property
     def items(self) -> typing.List["Event"]:
         """
-        items is a list of schema objects.
+        Items is a list of schema objects.
         """
         return typing.cast(
             typing.List["Event"],
@@ -584,7 +564,7 @@ class EventList(_kuber_definitions.Collection):
     @items.setter
     def items(self, value: typing.Union[typing.List["Event"], typing.List[dict]]):
         """
-        items is a list of schema objects.
+        Items is a list of schema objects.
         """
         cleaned: typing.List[Event] = []
         for item in value:
@@ -651,6 +631,7 @@ class EventSeries(_kuber_definitions.Definition):
         self,
         count: int = None,
         last_observed_time: "MicroTime" = None,
+        state: str = None,
     ):
         """Create EventSeries instance."""
         super(EventSeries, self).__init__(
@@ -661,17 +642,19 @@ class EventSeries(_kuber_definitions.Definition):
             "lastObservedTime": last_observed_time
             if last_observed_time is not None
             else MicroTime(),
+            "state": state if state is not None else "",
         }
         self._types = {
             "count": (int, None),
             "lastObservedTime": (MicroTime, None),
+            "state": (str, None),
         }
 
     @property
     def count(self) -> int:
         """
-        count is the number of occurrences in this series up to the
-        last heartbeat time.
+        Number of occurrences in this series up to the last
+        heartbeat time
         """
         return typing.cast(
             int,
@@ -681,16 +664,16 @@ class EventSeries(_kuber_definitions.Definition):
     @count.setter
     def count(self, value: int):
         """
-        count is the number of occurrences in this series up to the
-        last heartbeat time.
+        Number of occurrences in this series up to the last
+        heartbeat time
         """
         self._properties["count"] = value
 
     @property
     def last_observed_time(self) -> "MicroTime":
         """
-        lastObservedTime is the time when last Event from the series
-        was seen before last heartbeat.
+        Time when last Event from the series was seen before last
+        heartbeat.
         """
         return typing.cast(
             "MicroTime",
@@ -700,8 +683,8 @@ class EventSeries(_kuber_definitions.Definition):
     @last_observed_time.setter
     def last_observed_time(self, value: typing.Union["MicroTime", dict]):
         """
-        lastObservedTime is the time when last Event from the series
-        was seen before last heartbeat.
+        Time when last Event from the series was seen before last
+        heartbeat.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -710,6 +693,25 @@ class EventSeries(_kuber_definitions.Definition):
             )
         self._properties["lastObservedTime"] = value
 
+    @property
+    def state(self) -> str:
+        """
+        Information whether this series is ongoing or finished.
+        Deprecated. Planned removal for 1.18
+        """
+        return typing.cast(
+            str,
+            self._properties.get("state"),
+        )
+
+    @state.setter
+    def state(self, value: str):
+        """
+        Information whether this series is ongoing or finished.
+        Deprecated. Planned removal for 1.18
+        """
+        self._properties["state"] = value
+
     def __enter__(self) -> "EventSeries":
         return self
 
