@@ -5,22 +5,22 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_20.core_v1 import Container
-from kuber.v1_20.core_v1 import ContainerPort
-from kuber.v1_20.core_v1 import EnvFromSource
-from kuber.v1_20.core_v1 import EnvVar
-from kuber.v1_20.meta_v1 import LabelSelector
-from kuber.v1_20.core_v1 import Lifecycle
-from kuber.v1_20.meta_v1 import ListMeta
-from kuber.v1_20.meta_v1 import ObjectMeta
-from kuber.v1_20.core_v1 import PodTemplateSpec
-from kuber.v1_20.core_v1 import Probe
-from kuber.v1_20.core_v1 import ResourceRequirements
-from kuber.v1_20.core_v1 import SecurityContext
-from kuber.v1_20.meta_v1 import Status
-from kuber.v1_20.meta_v1 import StatusDetails
-from kuber.v1_20.core_v1 import VolumeDevice
-from kuber.v1_20.core_v1 import VolumeMount
+from kuber.v1_19.core_v1 import Container
+from kuber.v1_19.core_v1 import ContainerPort
+from kuber.v1_19.core_v1 import EnvFromSource
+from kuber.v1_19.core_v1 import EnvVar
+from kuber.v1_19.meta_v1 import LabelSelector
+from kuber.v1_19.core_v1 import Lifecycle
+from kuber.v1_19.meta_v1 import ListMeta
+from kuber.v1_19.meta_v1 import ObjectMeta
+from kuber.v1_19.core_v1 import PodTemplateSpec
+from kuber.v1_19.core_v1 import Probe
+from kuber.v1_19.core_v1 import ResourceRequirements
+from kuber.v1_19.core_v1 import SecurityContext
+from kuber.v1_19.meta_v1 import Status
+from kuber.v1_19.meta_v1 import StatusDetails
+from kuber.v1_19.core_v1 import VolumeDevice
+from kuber.v1_19.core_v1 import VolumeMount
 
 
 class Job(_kuber_definitions.Resource):
@@ -1150,8 +1150,6 @@ class JobStatus(_kuber_definitions.Definition):
         Represents time when the job was completed. It is not
         guaranteed to be set in happens-before order across separate
         operations. It is represented in RFC3339 form and is in UTC.
-        The completion time is only set when the job finishes
-        successfully.
         """
         return typing.cast(
             str,
@@ -1166,8 +1164,6 @@ class JobStatus(_kuber_definitions.Definition):
         Represents time when the job was completed. It is not
         guaranteed to be set in happens-before order across separate
         operations. It is represented in RFC3339 form and is in UTC.
-        The completion time is only set when the job finishes
-        successfully.
         """
         if isinstance(value, _datetime.datetime):
             value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -1179,9 +1175,8 @@ class JobStatus(_kuber_definitions.Definition):
     def conditions(self) -> typing.List["JobCondition"]:
         """
         The latest available observations of an object's current
-        state. When a job fails, one of the conditions will have
-        type == "Failed". More info: https://kubernetes.io/docs/conc
-        epts/workloads/controllers/jobs-run-to-completion/
+        state. More info: https://kubernetes.io/docs/concepts/worklo
+        ads/controllers/jobs-run-to-completion/
         """
         return typing.cast(
             typing.List["JobCondition"],
@@ -1194,9 +1189,8 @@ class JobStatus(_kuber_definitions.Definition):
     ):
         """
         The latest available observations of an object's current
-        state. When a job fails, one of the conditions will have
-        type == "Failed". More info: https://kubernetes.io/docs/conc
-        epts/workloads/controllers/jobs-run-to-completion/
+        state. More info: https://kubernetes.io/docs/concepts/worklo
+        ads/controllers/jobs-run-to-completion/
         """
         cleaned: typing.List[JobCondition] = []
         for item in value:
