@@ -5,10 +5,10 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_18.meta_v1 import ListMeta
-from kuber.v1_18.meta_v1 import ObjectMeta
-from kuber.v1_18.meta_v1 import Status
-from kuber.v1_18.meta_v1 import StatusDetails
+from kuber.v1_19.meta_v1 import ListMeta
+from kuber.v1_19.meta_v1 import ObjectMeta
+from kuber.v1_19.meta_v1 import Status
+from kuber.v1_19.meta_v1 import StatusDetails
 
 
 class FlowDistinguisherMethod(_kuber_definitions.Definition):
@@ -93,8 +93,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def metadata(self) -> "ObjectMeta":
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -105,8 +105,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -120,8 +120,8 @@ class FlowSchema(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "FlowSchemaSpec",
@@ -133,8 +133,8 @@ class FlowSchema(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -147,8 +147,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def status(self) -> "FlowSchemaStatus":
         """
         `status` is the current status of a FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "FlowSchemaStatus",
@@ -159,8 +159,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def status(self, value: typing.Union["FlowSchemaStatus", dict]):
         """
         `status` is the current status of a FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -515,8 +515,8 @@ class FlowSchemaList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         `metadata` is the standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -527,8 +527,8 @@ class FlowSchemaList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         `metadata` is the standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1285,8 +1285,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def metadata(self) -> "ObjectMeta":
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -1297,8 +1297,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1312,8 +1312,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         "request-priority". More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "PriorityLevelConfigurationSpec",
@@ -1325,8 +1325,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         "request-priority". More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1339,8 +1339,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def status(self) -> "PriorityLevelConfigurationStatus":
         """
         `status` is the current status of a "request-priority". More
-        info: https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        info: https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return typing.cast(
             "PriorityLevelConfigurationStatus",
@@ -1351,8 +1351,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def status(self, value: typing.Union["PriorityLevelConfigurationStatus", dict]):
         """
         `status` is the current status of a "request-priority". More
-        info: https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        info: https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1735,8 +1735,8 @@ class PriorityLevelConfigurationList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -1747,8 +1747,8 @@ class PriorityLevelConfigurationList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
